You are viewing a plain text version of this content. The canonical link for it is here.
Posted to muse-commits@ws.apache.org by wi...@apache.org on 2005/09/22 19:24:43 UTC

svn commit: r290991 - in /webservices/muse/trunk/src/examples/client/src: resource/target/.xmlbeans/lib/ resource/target/.xmlbeans/src/org/apache/ws/service/testresource/ resource/target/.xmlbeans/src/org/apache/ws/service/testresource/impl/ resource/t...

Author: wire
Date: Thu Sep 22 10:24:34 2005
New Revision: 290991

URL: http://svn.apache.org/viewcvs?rev=290991&view=rev
Log:
Added BaseFault support and ability to set properties

Added:
    webservices/muse/trunk/src/examples/client/src/wsdl/spec/wsx/
    webservices/muse/trunk/src/examples/client/src/wsdl/spec/wsx/WS-MetadataExchange-2004_09.wsdl
    webservices/muse/trunk/src/examples/client/src/wsdl/spec/wsx/WS-MetadataExchange-2004_09.xsd
Removed:
    webservices/muse/trunk/src/examples/client/src/wsdl/muse/disk.wsdl
    webservices/muse/trunk/src/examples/client/src/wsdl/muse/registry.wsdl
    webservices/muse/trunk/src/examples/client/src/wsdl/muse/subscription-manager.wsdl
Modified:
    webservices/muse/trunk/src/examples/client/src/resource/target/.xmlbeans/lib/testresource-xbeans.jar
    webservices/muse/trunk/src/examples/client/src/resource/target/.xmlbeans/src/org/apache/ws/service/testresource/NameDocument.java
    webservices/muse/trunk/src/examples/client/src/resource/target/.xmlbeans/src/org/apache/ws/service/testresource/PriceDocument.java
    webservices/muse/trunk/src/examples/client/src/resource/target/.xmlbeans/src/org/apache/ws/service/testresource/TestMetricDocument.java
    webservices/muse/trunk/src/examples/client/src/resource/target/.xmlbeans/src/org/apache/ws/service/testresource/TestMetricMetricType.java
    webservices/muse/trunk/src/examples/client/src/resource/target/.xmlbeans/src/org/apache/ws/service/testresource/TestOperationDocument.java
    webservices/muse/trunk/src/examples/client/src/resource/target/.xmlbeans/src/org/apache/ws/service/testresource/TestOperationResponseDocument.java
    webservices/muse/trunk/src/examples/client/src/resource/target/.xmlbeans/src/org/apache/ws/service/testresource/TestResourceResourcePropertiesDocument.java
    webservices/muse/trunk/src/examples/client/src/resource/target/.xmlbeans/src/org/apache/ws/service/testresource/impl/TestResourceResourcePropertiesDocumentImpl.java
    webservices/muse/trunk/src/examples/client/src/resource/target/TestResource/src/wsdl/testresource.wsdl

Modified: webservices/muse/trunk/src/examples/client/src/resource/target/.xmlbeans/lib/testresource-xbeans.jar
URL: http://svn.apache.org/viewcvs/webservices/muse/trunk/src/examples/client/src/resource/target/.xmlbeans/lib/testresource-xbeans.jar?rev=290991&r1=290990&r2=290991&view=diff
==============================================================================
Binary files - no diff available.

Modified: webservices/muse/trunk/src/examples/client/src/resource/target/.xmlbeans/src/org/apache/ws/service/testresource/NameDocument.java
URL: http://svn.apache.org/viewcvs/webservices/muse/trunk/src/examples/client/src/resource/target/.xmlbeans/src/org/apache/ws/service/testresource/NameDocument.java?rev=290991&r1=290990&r2=290991&view=diff
==============================================================================
--- webservices/muse/trunk/src/examples/client/src/resource/target/.xmlbeans/src/org/apache/ws/service/testresource/NameDocument.java (original)
+++ webservices/muse/trunk/src/examples/client/src/resource/target/.xmlbeans/src/org/apache/ws/service/testresource/NameDocument.java Thu Sep 22 10:24:34 2005
@@ -16,7 +16,7 @@
  */
 public interface NameDocument extends org.apache.xmlbeans.XmlObject
 {
-    public static final org.apache.xmlbeans.SchemaType type = (org.apache.xmlbeans.SchemaType)schemaorg_apache_xmlbeans.system.s22096BB57BC0444CD6372E5E2C1019E8.TypeSystemHolder.typeSystem.resolveHandle("nameca89doctype");
+    public static final org.apache.xmlbeans.SchemaType type = (org.apache.xmlbeans.SchemaType)schemaorg_apache_xmlbeans.system.s317106358396FAC8D56F0703078C4663.TypeSystemHolder.typeSystem.resolveHandle("nameca89doctype");
     
     /**
      * Gets the "Name" element

Modified: webservices/muse/trunk/src/examples/client/src/resource/target/.xmlbeans/src/org/apache/ws/service/testresource/PriceDocument.java
URL: http://svn.apache.org/viewcvs/webservices/muse/trunk/src/examples/client/src/resource/target/.xmlbeans/src/org/apache/ws/service/testresource/PriceDocument.java?rev=290991&r1=290990&r2=290991&view=diff
==============================================================================
--- webservices/muse/trunk/src/examples/client/src/resource/target/.xmlbeans/src/org/apache/ws/service/testresource/PriceDocument.java (original)
+++ webservices/muse/trunk/src/examples/client/src/resource/target/.xmlbeans/src/org/apache/ws/service/testresource/PriceDocument.java Thu Sep 22 10:24:34 2005
@@ -16,7 +16,7 @@
  */
 public interface PriceDocument extends org.apache.xmlbeans.XmlObject
 {
-    public static final org.apache.xmlbeans.SchemaType type = (org.apache.xmlbeans.SchemaType)schemaorg_apache_xmlbeans.system.s22096BB57BC0444CD6372E5E2C1019E8.TypeSystemHolder.typeSystem.resolveHandle("pricefd35doctype");
+    public static final org.apache.xmlbeans.SchemaType type = (org.apache.xmlbeans.SchemaType)schemaorg_apache_xmlbeans.system.s317106358396FAC8D56F0703078C4663.TypeSystemHolder.typeSystem.resolveHandle("pricefd35doctype");
     
     /**
      * Gets the "Price" element

Modified: webservices/muse/trunk/src/examples/client/src/resource/target/.xmlbeans/src/org/apache/ws/service/testresource/TestMetricDocument.java
URL: http://svn.apache.org/viewcvs/webservices/muse/trunk/src/examples/client/src/resource/target/.xmlbeans/src/org/apache/ws/service/testresource/TestMetricDocument.java?rev=290991&r1=290990&r2=290991&view=diff
==============================================================================
--- webservices/muse/trunk/src/examples/client/src/resource/target/.xmlbeans/src/org/apache/ws/service/testresource/TestMetricDocument.java (original)
+++ webservices/muse/trunk/src/examples/client/src/resource/target/.xmlbeans/src/org/apache/ws/service/testresource/TestMetricDocument.java Thu Sep 22 10:24:34 2005
@@ -16,7 +16,7 @@
  */
 public interface TestMetricDocument extends org.apache.xmlbeans.XmlObject
 {
-    public static final org.apache.xmlbeans.SchemaType type = (org.apache.xmlbeans.SchemaType)schemaorg_apache_xmlbeans.system.s22096BB57BC0444CD6372E5E2C1019E8.TypeSystemHolder.typeSystem.resolveHandle("testmetric9d60doctype");
+    public static final org.apache.xmlbeans.SchemaType type = (org.apache.xmlbeans.SchemaType)schemaorg_apache_xmlbeans.system.s317106358396FAC8D56F0703078C4663.TypeSystemHolder.typeSystem.resolveHandle("testmetric9d60doctype");
     
     /**
      * Gets the "TestMetric" element

Modified: webservices/muse/trunk/src/examples/client/src/resource/target/.xmlbeans/src/org/apache/ws/service/testresource/TestMetricMetricType.java
URL: http://svn.apache.org/viewcvs/webservices/muse/trunk/src/examples/client/src/resource/target/.xmlbeans/src/org/apache/ws/service/testresource/TestMetricMetricType.java?rev=290991&r1=290990&r2=290991&view=diff
==============================================================================
--- webservices/muse/trunk/src/examples/client/src/resource/target/.xmlbeans/src/org/apache/ws/service/testresource/TestMetricMetricType.java (original)
+++ webservices/muse/trunk/src/examples/client/src/resource/target/.xmlbeans/src/org/apache/ws/service/testresource/TestMetricMetricType.java Thu Sep 22 10:24:34 2005
@@ -15,7 +15,7 @@
  */
 public interface TestMetricMetricType extends org.apache.xmlbeans.XmlDouble
 {
-    public static final org.apache.xmlbeans.SchemaType type = (org.apache.xmlbeans.SchemaType)schemaorg_apache_xmlbeans.system.s22096BB57BC0444CD6372E5E2C1019E8.TypeSystemHolder.typeSystem.resolveHandle("testmetricmetrictype263atype");
+    public static final org.apache.xmlbeans.SchemaType type = (org.apache.xmlbeans.SchemaType)schemaorg_apache_xmlbeans.system.s317106358396FAC8D56F0703078C4663.TypeSystemHolder.typeSystem.resolveHandle("testmetricmetrictype263atype");
     
     /**
      * Gets the "ResetAt" attribute

Modified: webservices/muse/trunk/src/examples/client/src/resource/target/.xmlbeans/src/org/apache/ws/service/testresource/TestOperationDocument.java
URL: http://svn.apache.org/viewcvs/webservices/muse/trunk/src/examples/client/src/resource/target/.xmlbeans/src/org/apache/ws/service/testresource/TestOperationDocument.java?rev=290991&r1=290990&r2=290991&view=diff
==============================================================================
--- webservices/muse/trunk/src/examples/client/src/resource/target/.xmlbeans/src/org/apache/ws/service/testresource/TestOperationDocument.java (original)
+++ webservices/muse/trunk/src/examples/client/src/resource/target/.xmlbeans/src/org/apache/ws/service/testresource/TestOperationDocument.java Thu Sep 22 10:24:34 2005
@@ -16,7 +16,7 @@
  */
 public interface TestOperationDocument extends org.apache.xmlbeans.XmlObject
 {
-    public static final org.apache.xmlbeans.SchemaType type = (org.apache.xmlbeans.SchemaType)schemaorg_apache_xmlbeans.system.s22096BB57BC0444CD6372E5E2C1019E8.TypeSystemHolder.typeSystem.resolveHandle("testoperation72e1doctype");
+    public static final org.apache.xmlbeans.SchemaType type = (org.apache.xmlbeans.SchemaType)schemaorg_apache_xmlbeans.system.s317106358396FAC8D56F0703078C4663.TypeSystemHolder.typeSystem.resolveHandle("testoperation72e1doctype");
     
     /**
      * Gets the "TestOperation" element
@@ -40,7 +40,7 @@
      */
     public interface TestOperation extends org.apache.xmlbeans.XmlObject
     {
-        public static final org.apache.xmlbeans.SchemaType type = (org.apache.xmlbeans.SchemaType)schemaorg_apache_xmlbeans.system.s22096BB57BC0444CD6372E5E2C1019E8.TypeSystemHolder.typeSystem.resolveHandle("testoperation42e2elemtype");
+        public static final org.apache.xmlbeans.SchemaType type = (org.apache.xmlbeans.SchemaType)schemaorg_apache_xmlbeans.system.s317106358396FAC8D56F0703078C4663.TypeSystemHolder.typeSystem.resolveHandle("testoperation42e2elemtype");
         
         /**
          * A factory class with static methods for creating instances

Modified: webservices/muse/trunk/src/examples/client/src/resource/target/.xmlbeans/src/org/apache/ws/service/testresource/TestOperationResponseDocument.java
URL: http://svn.apache.org/viewcvs/webservices/muse/trunk/src/examples/client/src/resource/target/.xmlbeans/src/org/apache/ws/service/testresource/TestOperationResponseDocument.java?rev=290991&r1=290990&r2=290991&view=diff
==============================================================================
--- webservices/muse/trunk/src/examples/client/src/resource/target/.xmlbeans/src/org/apache/ws/service/testresource/TestOperationResponseDocument.java (original)
+++ webservices/muse/trunk/src/examples/client/src/resource/target/.xmlbeans/src/org/apache/ws/service/testresource/TestOperationResponseDocument.java Thu Sep 22 10:24:34 2005
@@ -16,7 +16,7 @@
  */
 public interface TestOperationResponseDocument extends org.apache.xmlbeans.XmlObject
 {
-    public static final org.apache.xmlbeans.SchemaType type = (org.apache.xmlbeans.SchemaType)schemaorg_apache_xmlbeans.system.s22096BB57BC0444CD6372E5E2C1019E8.TypeSystemHolder.typeSystem.resolveHandle("testoperationresponse2602doctype");
+    public static final org.apache.xmlbeans.SchemaType type = (org.apache.xmlbeans.SchemaType)schemaorg_apache_xmlbeans.system.s317106358396FAC8D56F0703078C4663.TypeSystemHolder.typeSystem.resolveHandle("testoperationresponse2602doctype");
     
     /**
      * Gets the "TestOperationResponse" element
@@ -40,7 +40,7 @@
      */
     public interface TestOperationResponse extends org.apache.xmlbeans.XmlObject
     {
-        public static final org.apache.xmlbeans.SchemaType type = (org.apache.xmlbeans.SchemaType)schemaorg_apache_xmlbeans.system.s22096BB57BC0444CD6372E5E2C1019E8.TypeSystemHolder.typeSystem.resolveHandle("testoperationresponse7424elemtype");
+        public static final org.apache.xmlbeans.SchemaType type = (org.apache.xmlbeans.SchemaType)schemaorg_apache_xmlbeans.system.s317106358396FAC8D56F0703078C4663.TypeSystemHolder.typeSystem.resolveHandle("testoperationresponse7424elemtype");
         
         /**
          * A factory class with static methods for creating instances

Modified: webservices/muse/trunk/src/examples/client/src/resource/target/.xmlbeans/src/org/apache/ws/service/testresource/TestResourceResourcePropertiesDocument.java
URL: http://svn.apache.org/viewcvs/webservices/muse/trunk/src/examples/client/src/resource/target/.xmlbeans/src/org/apache/ws/service/testresource/TestResourceResourcePropertiesDocument.java?rev=290991&r1=290990&r2=290991&view=diff
==============================================================================
--- webservices/muse/trunk/src/examples/client/src/resource/target/TestResource/src/wsdl/testresource.wsdl (original)
+++ webservices/muse/trunk/src/examples/client/src/resource/target/TestResource/src/wsdl/testresource.wsdl Thu Sep 22 10:24:34 2005
@@ -32,7 +32,7 @@
 					<sequence>
 						<element ref="tns:Name"/>
 						<element ref="tns:Price"/>
-						<element ref="tns:TestMetric" maxOccurs="unbounded" />
+						<element ref="tns:TestMetric" maxOccurs="unbounded"/>
 						<element ref="wsnt:Topic" maxOccurs="unbounded"/>
 						<element ref="wsnt:FixedTopicSet"/>
 						<element ref="wsnt:TopicExpressionDialects" maxOccurs="unbounded"/>

Added: webservices/muse/trunk/src/examples/client/src/wsdl/spec/wsx/WS-MetadataExchange-2004_09.wsdl
URL: http://svn.apache.org/viewcvs/webservices/muse/trunk/src/examples/client/src/wsdl/spec/wsx/WS-MetadataExchange-2004_09.wsdl?rev=290991&view=auto
==============================================================================
--- webservices/muse/trunk/src/examples/client/src/wsdl/spec/wsx/WS-MetadataExchange-2004_09.wsdl (added)
+++ webservices/muse/trunk/src/examples/client/src/wsdl/spec/wsx/WS-MetadataExchange-2004_09.wsdl Thu Sep 22 10:24:34 2005
@@ -0,0 +1,94 @@
+<?xml version='1.0' encoding='UTF-8' ?>
+<!--
+(c) 2004 BEA Systems Inc., Computer Associates International, Inc.,
+International Business Machines Corporation, Microsoft Corporation,
+Inc., SAP AG, Sun Microsystems, and webMethods. All rights reserved.
+
+Permission to copy and display the WS-MetadataExchange Specification
+(the "Specification"), in any medium without fee or royalty is hereby
+granted, provided that you include the following on ALL copies of the
+Specification that you make:
+
+1.	A link or URL to the Specification at this location.
+2.	The copyright notice as shown in the Specification.
+
+BEA Systems, Computer Associates, IBM, Microsoft, SAP, Sun, and
+webMethods (collectively, the "Authors") each agree to grant you a
+license, under royalty-free and otherwise reasonable,
+non-discriminatory terms and conditions, to their respective essential
+patent claims that they deem necessary to implement the
+WS-MetadataExchange Specification.
+
+THE SPECIFICATION IS PROVIDED "AS IS," AND THE AUTHORS MAKE NO
+REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED, INCLUDING, BUT NOT
+LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
+PURPOSE, NON-INFRINGEMENT, OR TITLE; THAT THE CONTENTS OF THE
+SPECIFICATION ARE SUITABLE FOR ANY PURPOSE; NOR THAT THE
+IMPLEMENTATION OF SUCH CONTENTS WILL NOT INFRINGE ANY THIRD PARTY
+PATENTS, COPYRIGHTS, TRADEMARKS OR OTHER RIGHTS.
+
+THE AUTHORS WILL NOT BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL,
+INCIDENTAL OR CONSEQUENTIAL DAMAGES ARISING OUT OF OR RELATING TO ANY
+USE OR DISTRIBUTION OF THE SPECIFICATIONS.
+
+The name and trademarks of the Authors may NOT be used in any manner,
+including advertising or publicity pertaining to the Specifications or
+their contents without specific, written prior permission. Title to
+copyright in the Specifications will at all times remain with the
+Authors.
+
+No other rights are granted by implication, estoppel or otherwise.
+-->
+
+<wsdl:definitions
+    targetNamespace='http://schemas.xmlsoap.org/ws/2004/09/mex'
+    xmlns:tns='http://schemas.xmlsoap.org/ws/2004/09/mex'
+    xmlns:wsa='http://schemas.xmlsoap.org/ws/2004/08/addressing'
+    xmlns:wsdl='http://schemas.xmlsoap.org/wsdl/'
+    xmlns:xs='http://www.w3.org/2001/XMLSchema' >
+
+  <wsdl:types>
+    <xs:schema
+        targetNamespace='http://schemas.xmlsoap.org/ws/2004/09/mex' >
+      <xs:include schemaLocation='WS-MetadataExchange-2004_09.xsd' />
+    </xs:schema>
+  </wsdl:types>
+
+  <wsdl:message name='GetMetadataMsg' >
+    <wsdl:part name='body' element='tns:GetMetadata' />
+  </wsdl:message>
+
+  <wsdl:message name='GetMetadataResponseMsg' >
+    <wsdl:part name='body' element='tns:Metadata' />
+  </wsdl:message>
+
+  <wsdl:message name='GetMsg' />
+
+  <wsdl:message name='GetResponseMsg' >
+    <wsdl:part name='body' type='tns:AnyXmlType' />
+  </wsdl:message>
+
+  <wsdl:portType name='MetadataExchange' >
+    <wsdl:operation name='GetMetadata' >
+      <wsdl:input
+          message='tns:GetMetadataMsg'
+          wsa:Action=
+           'http://schemas.xmlsoap.org/ws/2004/09/mex/GetMetadata/Request' />
+      <wsdl:output
+          message='tns:GetMetadataResponseMsg'
+          wsa:Action=
+           'http://schemas.xmlsoap.org/ws/2004/09/mex/GetMetadata/Response' />
+    </wsdl:operation>
+    <wsdl:operation name='Get' >
+      <wsdl:input
+          message='tns:GetMsg'
+          wsa:Action=
+           'http://schemas.xmlsoap.org/ws/2004/09/mex/Get/Request' />
+      <wsdl:output
+          message='tns:GetResponseMsg'
+          wsa:Action=
+           'http://schemas.xmlsoap.org/ws/2004/09/mex/Get/Response' />
+    </wsdl:operation>
+  </wsdl:portType>
+
+</wsdl:definitions>

Added: webservices/muse/trunk/src/examples/client/src/wsdl/spec/wsx/WS-MetadataExchange-2004_09.xsd
URL: http://svn.apache.org/viewcvs/webservices/muse/trunk/src/examples/client/src/wsdl/spec/wsx/WS-MetadataExchange-2004_09.xsd?rev=290991&view=auto
==============================================================================
--- webservices/muse/trunk/src/examples/client/src/wsdl/spec/wsx/WS-MetadataExchange-2004_09.xsd (added)
+++ webservices/muse/trunk/src/examples/client/src/wsdl/spec/wsx/WS-MetadataExchange-2004_09.xsd Thu Sep 22 10:24:34 2005
@@ -0,0 +1,114 @@
+<?xml version='1.0' encoding='UTF-8' ?>
+<!--
+(c) 2004 BEA Systems Inc., Computer Associates International, Inc.,
+International Business Machines Corporation, Microsoft Corporation,
+Inc., SAP AG, Sun Microsystems, and webMethods. All rights reserved. 
+
+Permission to copy and display the WS-MetadataExchange Specification
+(the "Specification"), in any medium without fee or royalty is hereby
+granted, provided that you include the following on ALL copies of the
+Specification that you make:
+
+1.	A link or URL to the Specification at this location.
+2.	The copyright notice as shown in the Specification.
+
+BEA Systems, Computer Associates, IBM, Microsoft, SAP, Sun, and
+webMethods (collectively, the "Authors") each agree to grant you a
+license, under royalty-free and otherwise reasonable,
+non-discriminatory terms and conditions, to their respective essential
+patent claims that they deem necessary to implement the
+WS-MetadataExchange Specification.
+
+THE SPECIFICATION IS PROVIDED "AS IS," AND THE AUTHORS MAKE NO
+REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED, INCLUDING, BUT NOT
+LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
+PURPOSE, NON-INFRINGEMENT, OR TITLE; THAT THE CONTENTS OF THE
+SPECIFICATION ARE SUITABLE FOR ANY PURPOSE; NOR THAT THE
+IMPLEMENTATION OF SUCH CONTENTS WILL NOT INFRINGE ANY THIRD PARTY
+PATENTS, COPYRIGHTS, TRADEMARKS OR OTHER RIGHTS.
+
+THE AUTHORS WILL NOT BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL,
+INCIDENTAL OR CONSEQUENTIAL DAMAGES ARISING OUT OF OR RELATING TO ANY
+USE OR DISTRIBUTION OF THE SPECIFICATIONS.
+
+The name and trademarks of the Authors may NOT be used in any manner,
+including advertising or publicity pertaining to the Specifications or
+their contents without specific, written prior permission. Title to
+copyright in the Specifications will at all times remain with the
+Authors.
+
+No other rights are granted by implication, estoppel or otherwise.
+-->
+
+<xs:schema
+    targetNamespace='http://schemas.xmlsoap.org/ws/2004/09/mex'
+    xmlns:tns='http://schemas.xmlsoap.org/ws/2004/09/mex'
+    xmlns:wsa='http://schemas.xmlsoap.org/ws/2004/08/addressing'
+    xmlns:xs='http://www.w3.org/2001/XMLSchema'
+    elementFormDefault='qualified'
+    blockDefault='#all' >
+
+  <xs:import
+      namespace='http://schemas.xmlsoap.org/ws/2004/08/addressing'
+      schemaLocation='../wsa/WS-Addressing-2004_08_10.xsd' />
+
+  <!-- Get Metadata request -->
+  <xs:element name='GetMetadata' >
+    <xs:complexType>
+      <xs:sequence>
+        <xs:element ref='tns:Dialect' minOccurs='0' />
+        <xs:element ref='tns:Identifier' minOccurs='0' />
+      </xs:sequence>
+      <xs:anyAttribute namespace='##other' processContents='lax' />
+    </xs:complexType>
+  </xs:element>
+
+  <xs:element name='Dialect' type='xs:anyURI' />
+  <xs:element name='Identifier' type='xs:anyURI' />
+
+  <!-- Get Metadata response -->
+  <xs:element name='Metadata' >
+    <xs:complexType>
+      <xs:sequence>
+        <xs:element ref='tns:MetadataSection'
+                    minOccurs='0'
+                    maxOccurs='unbounded' />
+      </xs:sequence>
+      <xs:anyAttribute namespace='##other' processContents='lax' />
+    </xs:complexType>
+  </xs:element>
+
+  <xs:element name='MetadataSection' >
+    <xs:complexType>
+      <xs:choice>
+        <xs:any namespace='##other'
+                processContents='lax'
+                minOccurs='0'
+                maxOccurs='unbounded' />
+        <xs:element ref='tns:MetadataReference' />
+        <xs:element ref='tns:Location' />
+      </xs:choice>
+      <xs:attribute name='Dialect' type='xs:anyURI' use='required' />
+      <xs:attribute name='Identifier' type='xs:anyURI' />
+      <xs:anyAttribute namespace='##other' processContents='lax' />
+    </xs:complexType>
+  </xs:element>
+
+  <xs:element name='MetadataReference'
+              type='wsa:EndpointReferenceType' />
+
+  <xs:element name='Location'
+              type='xs:anyURI' />
+
+  <!-- count(/s:Envelope/s:Body/*) = 0 for Get request -->
+
+  <!-- Get Response returns xs:any -->
+
+  <xs:complexType name='AnyXmlType' >
+    <xs:sequence>
+      <xs:any namespace='##any' processContents='lax' />
+    </xs:sequence>
+    <xs:anyAttribute namespace='##any' processContents='lax' />
+  </xs:complexType>
+
+</xs:schema>
--- webservices/muse/trunk/src/examples/client/src/resource/target/.xmlbeans/src/org/apache/ws/service/testresource/TestResourceResourcePropertiesDocument.java (original)
+++ webservices/muse/trunk/src/examples/client/src/resource/target/.xmlbeans/src/org/apache/ws/service/testresource/TestResourceResourcePropertiesDocument.java Thu Sep 22 10:24:34 2005
@@ -16,7 +16,7 @@
  */
 public interface TestResourceResourcePropertiesDocument extends org.apache.xmlbeans.XmlObject
 {
-    public static final org.apache.xmlbeans.SchemaType type = (org.apache.xmlbeans.SchemaType)schemaorg_apache_xmlbeans.system.s22096BB57BC0444CD6372E5E2C1019E8.TypeSystemHolder.typeSystem.resolveHandle("testresourceresourceproperties19ffdoctype");
+    public static final org.apache.xmlbeans.SchemaType type = (org.apache.xmlbeans.SchemaType)schemaorg_apache_xmlbeans.system.s317106358396FAC8D56F0703078C4663.TypeSystemHolder.typeSystem.resolveHandle("testresourceresourceproperties19ffdoctype");
     
     /**
      * Gets the "TestResourceResourceProperties" element
@@ -40,7 +40,7 @@
      */
     public interface TestResourceResourceProperties extends org.apache.xmlbeans.XmlObject
     {
-        public static final org.apache.xmlbeans.SchemaType type = (org.apache.xmlbeans.SchemaType)schemaorg_apache_xmlbeans.system.s22096BB57BC0444CD6372E5E2C1019E8.TypeSystemHolder.typeSystem.resolveHandle("testresourceresourceproperties6c62elemtype");
+        public static final org.apache.xmlbeans.SchemaType type = (org.apache.xmlbeans.SchemaType)schemaorg_apache_xmlbeans.system.s317106358396FAC8D56F0703078C4663.TypeSystemHolder.typeSystem.resolveHandle("testresourceresourceproperties6c62elemtype");
         
         /**
          * Gets the "Name" element
@@ -83,19 +83,44 @@
         void xsetPrice(org.apache.xmlbeans.XmlDouble price);
         
         /**
          * Gets the "TestMetric" element
          */
-        org.apache.ws.service.testresource.TestMetricMetricType getTestMetric();
+        org.apache.ws.service.testresource.TestMetricMetricType[] getTestMetricArray();
         
         /**
-         * Sets the "TestMetric" element
+         * Gets ith "TestMetric" element
          */
-        void setTestMetric(org.apache.ws.service.testresource.TestMetricMetricType testMetric);
+        org.apache.ws.service.testresource.TestMetricMetricType getTestMetricArray(int i);
         
         /**
-         * Appends and returns a new empty "TestMetric" element
+         * Returns number of "TestMetric" element
+         */
+        int sizeOfTestMetricArray();
+        
+        /**
+         * Sets array of all "TestMetric" element
+         */
+        void setTestMetricArray(org.apache.ws.service.testresource.TestMetricMetricType[] testMetricArray);
+        
+        /**
+         * Sets ith "TestMetric" element
+         */
+        void setTestMetricArray(int i, org.apache.ws.service.testresource.TestMetricMetricType testMetric);
+        
+        /**
+         * Inserts and returns a new empty value (as xml) as the ith "TestMetric" element
+         */
+        org.apache.ws.service.testresource.TestMetricMetricType insertNewTestMetric(int i);
+        
+        /**
+         * Appends and returns a new empty value (as xml) as the last "TestMetric" element
          */
         org.apache.ws.service.testresource.TestMetricMetricType addNewTestMetric();
+        
+        /**
+         * Removes the ith "TestMetric" element
+         */
+        void removeTestMetric(int i);
         
         /**
          * Gets array of all "Topic" elements
@@ -83,19 +83,44 @@
         
         /**
-         * Gets the "TestMetric" element
+         * Gets array of all "TestMetric" elements
          */

Modified: webservices/muse/trunk/src/examples/client/src/resource/target/.xmlbeans/src/org/apache/ws/service/testresource/impl/TestResourceResourcePropertiesDocumentImpl.java
URL: http://svn.apache.org/viewcvs/webservices/muse/trunk/src/examples/client/src/resource/target/.xmlbeans/src/org/apache/ws/service/testresource/impl/TestResourceResourcePropertiesDocumentImpl.java?rev=290991&r1=290990&r2=290991&view=diff
==============================================================================
--- webservices/muse/trunk/src/examples/client/src/resource/target/.xmlbeans/src/org/apache/ws/service/testresource/impl/TestResourceResourcePropertiesDocumentImpl.java (original)
+++ webservices/muse/trunk/src/examples/client/src/resource/target/.xmlbeans/src/org/apache/ws/service/testresource/impl/TestResourceResourcePropertiesDocumentImpl.java Thu Sep 22 10:24:34 2005
@@ -247,43 +247,97 @@
         }
         
         /**
          * Gets the "TestMetric" element
          */
-        public org.apache.ws.service.testresource.TestMetricMetricType getTestMetric()
+        public org.apache.ws.service.testresource.TestMetricMetricType[] getTestMetricArray()
+        {
+            synchronized (monitor())
+            {
+                check_orphaned();
+                java.util.List targetList = new java.util.ArrayList();
+                get_store().find_all_element_users(TESTMETRIC$4, targetList);
+                org.apache.ws.service.testresource.TestMetricMetricType[] result = new org.apache.ws.service.testresource.TestMetricMetricType[targetList.size()];
+                targetList.toArray(result);
+                return result;
+            }
+        }
+        
+        /**
+         * Gets ith "TestMetric" element
+         */
+        public org.apache.ws.service.testresource.TestMetricMetricType getTestMetricArray(int i)
         {
             synchronized (monitor())
             {
                 check_orphaned();
                 org.apache.ws.service.testresource.TestMetricMetricType target = null;
-                target = (org.apache.ws.service.testresource.TestMetricMetricType)get_store().find_element_user(TESTMETRIC$4, 0);
+                target = (org.apache.ws.service.testresource.TestMetricMetricType)get_store().find_element_user(TESTMETRIC$4, i);
                 if (target == null)
                 {
-                    return null;
+                    throw new IndexOutOfBoundsException();
                 }
                 return target;
             }
         }
         
         /**
-         * Sets the "TestMetric" element
+         * Returns number of "TestMetric" element
+         */
+        public int sizeOfTestMetricArray()
+        {
+            synchronized (monitor())
+            {
+                check_orphaned();
+                return get_store().count_elements(TESTMETRIC$4);
+            }
+        }
+        
+        /**
+         * Sets array of all "TestMetric" element
          */
-        public void setTestMetric(org.apache.ws.service.testresource.TestMetricMetricType testMetric)
+        public void setTestMetricArray(org.apache.ws.service.testresource.TestMetricMetricType[] testMetricArray)
+        {
+            synchronized (monitor())
+            {
+                check_orphaned();
+                arraySetterHelper(testMetricArray, TESTMETRIC$4);
+            }
+        }
+        
+        /**
+         * Sets ith "TestMetric" element
+         */
+        public void setTestMetricArray(int i, org.apache.ws.service.testresource.TestMetricMetricType testMetric)
         {
             synchronized (monitor())
             {
                 check_orphaned();
                 org.apache.ws.service.testresource.TestMetricMetricType target = null;
-                target = (org.apache.ws.service.testresource.TestMetricMetricType)get_store().find_element_user(TESTMETRIC$4, 0);
+                target = (org.apache.ws.service.testresource.TestMetricMetricType)get_store().find_element_user(TESTMETRIC$4, i);
                 if (target == null)
                 {
-                    target = (org.apache.ws.service.testresource.TestMetricMetricType)get_store().add_element_user(TESTMETRIC$4);
+                    throw new IndexOutOfBoundsException();
                 }
                 target.set(testMetric);
             }
         }
         
         /**
-         * Appends and returns a new empty "TestMetric" element
+         * Inserts and returns a new empty value (as xml) as the ith "TestMetric" element
+         */
+        public org.apache.ws.service.testresource.TestMetricMetricType insertNewTestMetric(int i)
+        {
+            synchronized (monitor())
+            {
+                check_orphaned();
+                org.apache.ws.service.testresource.TestMetricMetricType target = null;
+                target = (org.apache.ws.service.testresource.TestMetricMetricType)get_store().insert_element_user(TESTMETRIC$4, i);
+                return target;
+            }
+        }
+        
+        /**
+         * Appends and returns a new empty value (as xml) as the last "TestMetric" element
          */
         public org.apache.ws.service.testresource.TestMetricMetricType addNewTestMetric()
         {
@@ -293,6 +347,18 @@
                 org.apache.ws.service.testresource.TestMetricMetricType target = null;
                 target = (org.apache.ws.service.testresource.TestMetricMetricType)get_store().add_element_user(TESTMETRIC$4);
                 return target;
+            }
+        }
+        
+        /**
+         * Removes the ith "TestMetric" element
+         */
+        public void removeTestMetric(int i)
+        {
+            synchronized (monitor())
+            {
+                check_orphaned();
+                get_store().remove_element(TESTMETRIC$4, i);
             }
         }
         
@@ -247,43 +247,97 @@
         
         /**
-         * Gets the "TestMetric" element
+         * Gets array of all "TestMetric" elements
          */

Modified: webservices/muse/trunk/src/examples/client/src/resource/target/TestResource/src/wsdl/testresource.wsdl
URL: http://svn.apache.org/viewcvs/webservices/muse/trunk/src/examples/client/src/resource/target/TestResource/src/wsdl/testresource.wsdl?rev=290991&r1=290990&r2=290991&view=diff
==============================================================================